<?php
/**
 * @var $block \PortalPeople\ShippingFields\Block\Adminhtml\Order\Edit\ShippingFields
 */
?>
<div class="admin__page-section-item order-shipping-fields-edit">
    <div class="admin__page-section-item-title">
        <span class="title"><?= __('Shipping Fields') ?></span>
    </div>
    <div class="admin__page-section-item-content">
        <div class="admin__field">
            <label class="admin__field-label" for="order[shipping_date]">
                <?= __('Preferred Shipping Date') ?>
            </label>
            <div class="admin__field-control">
                <input type="date" 
                       id="order_shipping_date" 
                       name="order[shipping_date]" 
                       class="admin__control-text" 
                       value="<?= $block->escapeHtmlAttr($block->getShippingDate()) ?>"/>
            </div>
        </div>
        
        <div class="admin__field">
            <label class="admin__field-label" for="order[shipping_message]">
                <?= __('Shipping Message') ?>
            </label>
            <div class="admin__field-control">
                <textarea id="order_shipping_message" 
                          name="order[shipping_message]" 
                          class="admin__control-textarea" 
                          rows="3"><?= $block->escapeHtml($block->getShippingMessage()) ?></textarea>
            </div>
        </div>
    </div>
</div>
